import { strictEqual } from 'assert';
import { bibtex, bibtexTidy, test } from './utils';

const input = bibtex`
@article{Hess2012a,
	abstract = {Stated choice surveys are used extensively in the study of choice behaviour across many different areas of research, notably in transport. One of their main characteristics in comparison with most types of revealed preference (RP) surveys is the ability to capture behaviour by the same respondent under varying choice scenarios. While this ability to capture multiple choices is generally seen as an advantage, there is a certain amount of unease about survey length. The precise definition about what constitutes a large number of choice tasks however varies across disciplines, and it is not uncommon to see surveys with up to twenty tasks per respondent in some areas. The argument against this practice has always been one of reducing respondent engagement, which could be interpreted as a result of fatigue or boredom, with frequent reference to the findings of Bradley and Daly (1994) who showed a significant drop in utility scale, i.e. an increase in error, as a respondent moved from one choice experiment to the next, an effect they related to respondent fatigue. While the work by Bradley and Daly has become a standard reference in this context, it should be recognised that not only was the fatigue part of the work based on a single dataset, but the state-of-the-art and the state-of-practice in stated choice survey design and implementation has moved on significantly since their study. In this paper, we review other literature and present a more comprehensive study investigating evidence of respondent fatigue across a larger number of different surveys. Using a comprehensive testing framework employing both Logit and mixed Logit structures, we provide strong evidence that the concerns about fatigue in the literature are possibly overstated, with no clear decreasing trend in scale across choice tasks in any of our studies. For the data sets tested, we find that accommodating any scale heterogeneity has little or no impact on substantive model results, that the role of constants generally decreases as the survey progresses, and that there is evidence of significant attribute level (as opposed to scale) heterogeneity across choice tasks. {\textcopyright} 2011 Elsevier Ltd.},
	author = {Hess, Stephane and Hensher, David A. and Daly, Andrew},
	doi = {10.1016/j.tra.2011.11.008},
	file = {:C$\backslash$:/Users/amitrani/Documents/Mendeley/Hess, Hensher, Daly - 2012 - Not bored yet - Revisiting respondent fatigue in stated choice experiments.pdf:pdf},
	isbn = {0965-8564},
	issn = {09658564},
	journal = {Transportation Research Part A: Policy and Practice},
	keywords = {Fatigue,Learning,Multiple data sets,Scale,Stated choice experiments,Willingness to pay},
	number = 3,
	pages = {626--644},
	title = {{Not bored yet - Revisiting respondent fatigue in stated choice experiments}},
	volume = 46,
	year = 2012
}
@inproceedings{Hess2012b,
	abstract = {Stated choice surveys are used extensively in the study of choice behaviour across many different areas of research, notably in transport. One of their main characteristics in comparison with most types of revealed preference (RP) surveys is the ability to capture behaviour by the same respondent under varying choice scenarios. While this ability to capture multiple choices is generally seen as an advantage, there is a certain amount of unease about survey length. The precise definition about what constitutes a large number of choice tasks however varies across disciplines, and it is not uncommon to see surveys with up to twenty tasks per respondent in some areas. The argument against this practice has always been one of reducing respondent engagement, which could be interpreted as a result of fatigue or boredom, with frequent reference to the findings of Bradley and Daly (1994) who showed a significant drop in utility scale, i.e., an increase in error, as a respondent moved from one choice experiment to the next, an effect they related to respondent fatigue. While the work by Bradley and Daly has become a standard reference in this context, it should be recognised that not only was the fatigue part of the work based on a single dataset, but the state-of-the-art and the state-of-practice in stated choice survey design and implementation has moved on significantly since their study. In this paper, we review other literature and present a more comprehensive study investigating evidence of respondent fatigue across a larger number of different surveys. Using a comprehensive testing framework employing both Logit and mixed Logit structures, we provide strong evidence that the concerns about fatigue in the literature are possibly overstated, with no clear decreasing trend in scale across choice tasks in any of our studies. For the data sets tested, we find that accommodating any scale heterogeneity has little or no impact on substantive model results, that the role of constants generally decreases as the survey progresses, and that there is evidence of significant attribute level (as opposed to scale) heterogeneity across choice tasks.},
	author = {Hess, Stephane and Hensher, DA and Daly, Andrew},
	booktitle = {Transportation Research Board, 91st Annual Meeting},
	file = {:C$\backslash$:/Users/amitrani/Documents/Mendeley/Hess, Hensher, Daly - 2012 - Not bored yet–Revisiting respondent fatigue in stated choice experiments.pdf:pdf},
	isbn = {0965-8564},
	keywords = {fatigue,learning,multiple data sets,scale,stated choice experiments,willingness to pay},
	pages = {1--26},
	title = {{Not bored yet–Revisiting respondent fatigue in stated choice experiments}},
	url = {http://www.sciencedirect.com/science/article/pii/S0965856411001777},
	volume = 46,
	year = 2012
}
@inproceedings{Hess2012c,
	abstract = {Recent interest in the topic of random scale heterogeneity in discrete choice data has led to the development of specialised tools such as the G-MNL model, as well as repeated claims that studies which fail to separate scale heterogeneity from heterogeneity in individual coefficients are likely to produce biased results. Contrary to this, Hess and Rose (2012) show that separate identification of the two components is not in fact possible in a random coefficients model using a typical linear in parameters specification, and that any gains in performance are potentially just the result of more flexible distributional assumptions. On the other hand, linking scale heterogeneity to measured characteristics of the respondents is likely to yield only limited insights, while using respondent reported measures of survey understanding or analyst captured measures such as survey response time puts an analyst at risk of measurement error and endogeneity bias. The contribution made in this paper is to put forward a hybrid model in which survey engagement is treated as a latent variable which is used to model the values of a number of indicators of survey engagement in a measurement model component, as well as explaining scale heterogeneity within the choice model. This model overcomes some of the shortcomings of earlier work, permitting us to link part of the heterogeneity across respondents to differences in scale, while also allowing us to make use of indicators of survey engagement without risk of endogeneity bias. Results from an empirical application show a strong link between the two model components as well as arguably more reasonable substantive outputs for the choice model component. ?? 2013 Elsevier BV. All rights reserved.},
	author = {Hess, Stephane and Stathopoulos, Amanda},
	booktitle = {Transportation Research Board, 91st Annual Meeting},
	doi = {10.1016/j.jocm.2013.03.005},
	file = {:C$\backslash$:/Users/amitrani/Documents/Mendeley/Hess, Stathopoulos - 2012 - Linking response quality to survey engagement A combined random scale and latent variable approach.pdf:pdf},
	issn = 17555345,
	keywords = {Hybrid model,Latent variables,Random scale,Stated choice,Survey engagement},
	pages = {1--12},
	pmid = 18394806,
	title = {{Linking response quality to survey engagement: A combined random scale and latent variable approach}},
	volume = 7,
	year = 2012
}
@inproceedings{Hess2012d,
	author = {Hess, Stephane and Rose, John M.},
	booktitle = {Transportation Research Board, 91st Annual Meeting},
	file = {:C$\backslash$:/Users/amitrani/Documents/Mendeley/Hess, Rose - 2012 - Disentangling scale and coefficient heterogeneity in random coefficients models an exercise in futility.pdf:pdf},
	keywords = {discrete choice,geneity,mixed logit,random scale,scale hetero-,taste heterogeneity},
	number = {0},
	pages = {1--23},
	title = {{Disentangling scale and coefficient heterogeneity in random coefficients models : an exercise in futility}},
	volume = 44,
	year = 2012
}
@inproceedings{Hess2012e,
	abstract = {In recent years, we have seen an explosion of research seeking to understand the role that rules and heuristics might play in improving the predictive capability of discrete choice models, as well as delivering willingness to pay estimates for specific attributes that may (and often do) differ significantly from estimates based on a model specification that assumes all attributes are relevant. This paper adds to that literature in one important way--it explicitly recognises the endogeneity issues raised by typical attribute non-attendance treatments and conditions attribute parameters on underlying unobserved attribute importance ratings. We develop a hybrid model system involving attribute processing and outcome choice models in which latent variables are introduced as explanatory variables in both parts of the model, explaining the answers to attribute processing questions and explaining heterogeneity in marginal sensitivities in the choice model. The resulting empirical model explains how lower latent attribute importance leads to a higher probability of indicating that an attribute was ignored or that it was ranked as less important, as well as increasing the probability of a reduced value for the associated marginal utility coefficient in the choice model. The model does so by treating the answers to information processing questions as dependent rather than explanatory variables, hence avoiding potential risk of endogeneity bias and measurement error.},
	author = {Hess, Stephane and Hensher, David A.},
	booktitle = {Transportation Research Board, 91st Annual Meeting},
	doi = {10.1007/s11116-012-9420-y},
	file = {:C$\backslash$:/Users/amitrani/Documents/Mendeley/Hess, Hensher - 2012 - Making use of respondent reported processing information to understand attribute importance A latent variable sca.pdf:pdf},
	isbn = {0049-4488},
	issn = {00494488},
	keywords = {Attribute ignoring,Attribute importance,Attribute relevance,Information processing,Non-attendance,Stated choice},
	number = 2,
	pages = {397--412},
	title = {{Making use of respondent reported processing information to understand attribute importance: A latent variable scaling approach}},
	volume = 40,
	year = 2012
}
@inproceedings{Hess2012f,
	abstract = {Wordcount: 5,606 words, 4 tables = 6,606 words 5 Abstract 6 There is growing interest in the notion that when responding to the hypothet-7 ical scenarios faced in a stated choice survey, a respondent may make his/her 8 choices on the basis of only a subset of the presented attributes. Research on 9 how to adequately capture such behaviour in data, and how to accommodate it 10 in our models, has made substantial headway in recent years. Two main schools 11 of thought exist for the reasons of such attribute non-attendance. Some see it 12 as evidence of respondent burden, while others will point to the notion that re-13 spondents decide first which attributes are relevant, before making their choices 14 based on that subset of attributes. Either way, the impact of any unimportant 15 attributes on the estimates of other valuations is unclear, where the focus in the 16 literature has been on the sample level estimates only of the attribute in ques-17 tion. This paper presents evidence from a two stage survey where the second stage 18 eliminates attributes deemed unimportant by a respondent in the first stage. Our 19 analysis shows no evidence of systematic differences between the results of the 20 two games, suggesting that the impact of such attributes on other valuations is 21 minimal at best. This further leads to the conclusion that analysts should not 22 be overly concerned about respondent burden, but should rather include all at-23 tributes that may be relevant, and allow the respondent to filter out those that 24 play no role. Tel: +44 (0)113 34 36611, Fax: +44 (0)113 343 5334},
	author = {Hess, Stephane},
	booktitle = {Transportation Research Board, 91st Annual Meeting},
	file = {:C$\backslash$:/Users/amitrani/Documents/Mendeley/Hess - 2012 - Impact of unimportant attributes in stated choice surveys.pdf:pdf},
	keywords = {attribute ignoring,attribute relevance,dent burden,information processing,non-attendance,respon-,stated choice},
	number = 2010,
	pages = {1--23},
	title = {{Impact of unimportant attributes in stated choice surveys}},
	url = {http://trid.trb.org/view.aspx?id=1129503},
	volume = 14,
	year = 2012
}
@article{Hess2013,
	abstract = {With the growing interest in the topic of attribute non-attendance, there is now widespread use of latent class (LC) structures aimed at capturing such behaviour, across a number of different fields. Specifically, these studies rely on a confirmatory LC model, using two separate values for each coefficient, one of which is fixed to zero while the other is estimated, and then use the obtained class probabilities as an indication of the degree of attribute non-attendance. In the present paper, we argue that this approach is in fact misguided, and that the results are likely to be affected by confounding with regular taste heterogeneity. We contrast the confirmatory model with an exploratory LC structure in which the values in both classes are estimated. We also put forward a combined latent class mixed logit model (LC-MMNL) which allows jointly for attribute non-attendance and for continuous taste heterogeneity. Across three separate case studies, the exploratory LC model clearly rejects the confirmatory LC approach and suggests that rates of non-attendance may be much lower than what is suggested by the standard model, or even zero. The combined LC-MMNL model similarly produces significant improvements in model fit, along with substantial reductions in the implied rate of attribute non-attendance, in some cases even eliminating the phenomena across the sample population. Our results thus call for a reappraisal of the large body of recent work that has implied high rates of attribute non-attendance for some attributes. Finally, we also highlight a number of general issues with attribute non-attendance, in particular relating to the computation of willingness to pay measures.},
	author = {Hess, Stephane and Stathopoulos, Amanda and Campbell, Danny and O'Neill, Vikki and Caussade, Sebastian},
	doi = {10.1007/s11116-012-9438-1},
	file = {:C$\backslash$:/Users/amitrani/Documents/Mendeley/Hess et al. - 2013 - It's not that I don't care, I just don't care very much Confounding between attribute non-attendance and taste hete.pdf:pdf},
	isbn = 1111601294381,
	issn = {00494488},
	journal = {Transportation},
	keywords = {Attribute ignoring,Attribute non-attendance,Choice modelling,Stated choice,Taste heterogeneity},
	number = 3,
	pages = {583--607},
	title = {{It's not that I don't care, I just don't care very much: Confounding between attribute non-attendance and taste heterogeneity}},
	volume = 40,
	year = 2013
}
@inproceedings{Hess2013a,
	abstract = {In a large-scale urban evacuation necessitated by a disaster, many people can evacuate in their own automobiles, but evacuating individuals and families who do not have cars poses a great logistical challenge that many cities, counties, and states cannot overcome. Most emergency operations plans for large urbanized areas are insufficient in describing in specific and measurable terms how a major evacuation could be successfully conducted. This study systematically reviews the challenge of multimodal evacuation planning and presents a detailed literature review of published research and government documents to identify barriers to the enhancement of multimodal evacuation planning through the use of high-capacity vehicles to transport those who cannot evacuate on their own. Findings suggest that despite knowledge about multimodal transportation and the importance of integrating multimodalism into evacuation planning, most state and local governments do not apply the planning processes, training exercises, and resources necessary to evacuate households without automobiles. A research agenda for furthering multimodal evacuation planning is outlined, and recommendations are made for providing adequate multimodal transport during large-scale urban evacuations.},
	author = {Hess, Daniel Baldwin and Conley, Brian W and Farrell, Christina M},
	booktitle = {Transportation Research Board, 92nd Annual Meeting},
	doi = {10.3141/2376-02},
	file = {:C$\backslash$:/Users/amitrani/Documents/Mendeley/Hess, Conley, Farrell - 2013 - Improving Transportation Resource Coordination for Multimodal Evacuation Planning Literature Review and R.pdf:pdf},
	issn = {0361-1981},
	number = 2376,
	pages = {11--19},
	title = {{Improving Transportation Resource Coordination for Multimodal Evacuation Planning Literature Review and Research Agenda}},
	year = 2013
}
@inproceedings{Hess2013b,
	abstract = {Using data from a stated preference survey conducted in the UK, we show how the relative importance that rail travellers attach to reductions in greenhouse gas emissions and faster journey times varies strongly as a function of underlying attitudes towards the environment. We specify a latent class structure that allocates respondents to two classes with substantially different valuations of greenhouse gas emissions, and show how the allocation of a given respondent to either class is a function of underlying attitudes that also drive the answers to a number of attitudinal questions. We also show how these underlying attitudes are a function of a number of socio-demographic characteristics, with female respondents, older respondents, and respondents with a university degree having a stronger pro-environmental attitude, with the opposite applying to respondents with regular car access. ?? 2013 Elsevier Ltd.},
	author = {Hess, Stephane and Shires, Jeremy and Jopson, Ann},
	booktitle = {Transportation Research Board, 92nd Annual Meeting},
	doi = {10.1016/j.trd.2013.07.003},
	file = {:C$\backslash$:/Users/amitrani/Documents/Mendeley/Hess, Shires, Jopson - 2013 - Accommodating underlying pro-environmental attitudes in a rail travel context Application of a latent vari.pdf:pdf},
	isbn = {1361-9209},
	issn = 13619209,
	keywords = {Environmental attitudes,Greenhouse gas emissions,Rail transport,Stated preference method},
	pages = {42--48},
	title = {{Accommodating underlying pro-environmental attitudes in a rail travel context: Application of a latent variable latent class specification}},
	volume = 25,
	year = 2013
}
@inproceedings{Hess2013c,
	abstract = {Income is recognised as a key variable influencing consumer behaviour, most notably in terms of a strong link with cost sensitivity. This is sup-ported by a large body of empirical evidence using choice modelling tech-niques. Unfortunately, income information as available in most datasets used for modelling is affected by a number of issues; (1) it is measured as a categorical rather than as a continuous variable, (2) many respondents fail to provide income information, (3) the reported income is potentially correlated with other unobserved factors, and (4) there is scope for delib-erate under or overstating of income by respondents. In the present paper, we propose to deal with these issues by replacing reported income with a latent income variable in the choice models, which at the same time is also used to explain the stated income in a measurement model. The proposed structure has a number of theoretical advantages. In comparison with using stated income, we should deal with some of the measurement error and bias issues. In comparison with using imputation of missing values, our model draws not just on data on stated income for those re-spondents without missing information, but the simultaneous estimation with the choice model means that the observed choices also inform the la-tent income variable. Two empirical applications using stated and revealed preference data illustrate the good performance of the method in practice.},
	author = {Hess, Stephane and Daly, Andrew and Dumont, Jeff and Sanko, Nobuhiro},
	booktitle = {Transportation Research Board, 92nd Annual Meeting},
	file = {:C$\backslash$:/Users/amitrani/Documents/Mendeley/Hess et al. - 2013 - When explanatory variables are unobserved the example of latent income.pdf:pdf},
	keywords = {discrete choice,latent variables,missing income,random het-erogeneity},
	pages = {1--14},
	title = {{When explanatory variables are unobserved: the example of latent income}},
	year = 2013
}
@inproceedings{Hess2014,
	abstract = {5 An increasing number of choice models models have been proposed to examine respondents' use 6 of heterogeneous decision rules. The focus has been on revealing which paradigm fits best for a given 7 respondent or class of respondents, or for a given choice characteristic. On the other hand, limited 8 effort has gone towards understanding the motivation behind the use of different decision rules. This 9 paper presents a model that creates a link between real world behavioural indicators and the use of 10 decision paradigms in a stated choice context. An empirical application is developed as a latent class 11 mixture between regret minimisation and utility maximisation where the allocation to a given class is 12 driven in part by a latent variable which also, in a separate measurement model, explains respondents' 13 stated satistfaction with their real world reference commute journey (in terms of differences between 14 experienced and ideal travel performance). Results reveal a linkage between the likely decision rule 15 and the stated satisfaction with the real world commute where the most regret-prone respondents in 16 our sample are more likely to have aligned their real-life commute performance to their aspirational 17 values.},
	author = {Hess, Stephane},
	booktitle = {Transportation Research Board, 93rd Annual Meeting},
	file = {:C$\backslash$:/Users/amitrani/Documents/Mendeley/Hess - 2014 - Linking the decision process to indicators of real world perceptions in a latent variable latent class approach.pdf:pdf},
	keywords = {2 figures and 2,265 words,5,6,decision rules,hybrid models,latent class,random regret,random utility,tables,word count},
	number = {0},
	title = {{Linking the decision process to indicators of real world perceptions in a latent variable latent class approach}},
	volume = 44,
	year = 2014
}
@inproceedings{Hess2014a,
	abstract = {An increasing number of studies of choice behaviour are looking at Random Regret Minimisation (RRM) as an alternative to the well established Random Utility Maximisation (RUM) framework. Empirical evidence tends to show small differences in performance between the two approaches, with the implied preference between the models being dataset specific. In the present paper, we discuss how in the context of choice tasks involving an opt out alternative, the differences are potentially more clear cut. Specifically, we hypothesise that when opt out alternatives are framed as a rejection of all the available alternatives, this is likely to have a detrimental impact on the performance of RRM, while the performance of RUM suffers more than RRM when the opt out is framed as a respondent being indifferent between the alternatives on offer. We provide empirical support for these hypotheses through two case studies, using the two different types of opt out alternatives. Our findings suggest that analysts need to carefully evaluate their choice of model structure in the presence of opt out alternatives, while any a priori preference for a given model structure should be taken into account in survey framing. ?? 2014 Elsevier Ltd.},
	author = {Hess, Stephane and Beck, Matthew J. and Chorus, Caspar G.},
	booktitle = {Transportation Research Board, 93rd Annual Meeting},
	doi = {10.1016/j.tra.2014.04.004},
	file = {:C$\backslash$:/Users/amitrani/Documents/Mendeley/Hess, Beck, Chorus - 2014 - Contrasts between utility maximisation and regret minimisation in the presence of opt out alternatives.pdf:pdf},
	isbn = {0965-8564},
	issn = {09658564},
	keywords = {Decision rules,Opt out alternatives,Random regret minimisation,Stated choice},
	number = 1,
	pages = {1--12},
	title = {{Contrasts between utility maximisation and regret minimisation in the presence of opt out alternatives}},
	volume = 66,
	year = 2014
}
@inproceedings{Hess2014b,
	abstract = {This paper presents a novel application in route choice modelling using Global Positioning System (GPS) data, focussing on heavy goods vehicles which typically make longer journeys with decisions potentially underpinned by different priorities from those used by car drivers. The scope of the study is larger than many previous ones, using the entire road network of England. Making use of the error components model put forward for route choice by Frejinger and Bierlaire (2007), the work reveals low elasticities in response to changes in travel time, reflecting the limited opportunity for avoiding specific roads on long distance journeys by heavy goods vehicles.},
	author = {Hess, Stephane and Quddus, Mohammed and Rieser-Sch{\"{u}}ssler, Nadine and Daly, Andrew},
	booktitle = {Transportation Research Board, 93rd Annual Meeting},
	doi = {10.1016/j.tre.2015.01.010},
	file = {:C$\backslash$:/Users/amitrani/Documents/Mendeley/Hess et al. - 2014 - Developing advanced route choice models for heavy goods vehicles using GPS data.pdf:pdf},
	isbn = {1366-5545},
	issn = 13665545,
	keywords = {Error components,GPS data,Heavy goods vehicles,Route choice},
	pages = {29--44},
	title = {{Developing advanced route choice models for heavy goods vehicles using GPS data}},
	volume = 77,
	year = 2014
}
@inproceedings{Hess2015,
	author = {Hess, S and Chorus, CG},
	booktitle = {Transportation Research Board, 94th Annual Meeting},
	file = {:C$\backslash$:/Users/amitrani/Documents/Mendeley/Hess, Chorus - 2015 - Utility Maximisation and Regret Minimisation A Mixture of a Generalisation.pdf:pdf},
	isbn = 9781784410728,
	pages = {31 -- 48},
	title = {{Utility Maximisation and Regret Minimisation: A Mixture of a Generalisation}},
	url = {https://books.google.cl/books?hl=es{\&}lr={\&}id=RwSLBgAAQBAJ{\&}oi=fnd{\&}pg=PA31{\&}ots=bvrG3C87Tx{\&}sig=4tfRoUmlciwPBylLq5aT6Hakxrc},
	year = 2015
}
@article{Hess2016,
	abstract = {See, stats, and : https : / / www . researchgate . net / publication / 309734001 A , heteroscedasticity , non - linearity , reference dependence . . . Article CITATIONS 0 READS 9 6 , including : Stephane University 111 , 122 SEE Andrew University 82 , 841 SEE Thijs University 25 SEE All - text , letting . Available : Stephane Retrieved : 08 Abstract In early 2014 , the UK Department for Transport (DfT) commissioned the first national value of travel time (VTT) study since the mid - 1990s . This paper presents the methodological work undertaken for this study , with important innovations along a number of dimensions , both in terms of survey design and modelling methodology . Our findings show a rich pattern of heterogeneity across the travelling public , in terms of an impact on the VTT by both person and trip characteristics , as well as a major role for a number of characteristics that relate to the specific choices faced in a hypothetical stated choice setting , including reference dependence and non - linearities in sensitivities . We also discuss how these behavioural values were translated into values for use in appraisal , and the challenges faced when doing this on the basis of results obtained with advanced models .},
	author = {Hess, Stephane and Daly, Andrew and Dekker, Thijs and Cabral, Manuel Ojeda and Batley, Richard},
	file = {:C$\backslash$:/Users/amitrani/Documents/Mendeley/Hess et al. - 2016 - A framework for capturing heterogeneity , heteroscedasticity , non - linearity , reference dependence and design ar.pdf:pdf},
	journal = {Transportation Research Part B Methodological},
	number = {November},
	title = {{A framework for capturing heterogeneity , heteroscedasticity , non - linearity , reference dependence and design artefacts in value of time research}},
	year = 2016
}
@article{Hess2016a,
	author = {Hess, Stephane and B{\"{o}}rjesson, Maria},
	file = {:C$\backslash$:/Users/amitrani/Documents/Mendeley/Hess, B{\"{o}}rjesson - 2016 - Understanding attitudes towards congestion pricing a latent variable investigation with data from four cities.pdf:pdf},
	journal = {Transportation Letters The International Journal of Transportation Research},
	number = {December},
	title = {{Understanding attitudes towards congestion pricing: a latent variable investigation with data from four cities}},
	year = 2016
}
@inproceedings{Hess2017,
	address = {Washington D.C.},
	author = {Hess, Stephane and Daly, Andrew and B{\"{o}}rjesson, Maria},
	booktitle = {Transportation Research Board, 96th Annual Meeting},
	file = {:C$\backslash$:/Users/amitrani/Documents/Mendeley/Hess, Daly, B{\"{o}}rjesson - 2017 - A critical appraisal of the use of simple time-money trade-offs for appraisal value of time measures.pdf:pdf},
	title = {{A critical appraisal of the use of simple time-money trade-offs for appraisal value of time measures}},
	year = 2017
}
@inproceedings{Hess2017a,
	author = {Hess, Jacob Robert},
	booktitle = {Transportation Research Board, 96th Annual Meeting},
	file = {:C$\backslash$:/Users/amitrani/Documents/Mendeley/Hess - 2017 - Outlier Mining Based Traffic Incident Detection Using Big Data.pdf:pdf},
	number = 765,
	title = {{Outlier Mining Based Traffic Incident Detection Using Big Data}},
	year = 2017
}`;

const output = bibtex`
@article{Hess2012a,
	abstract = {Stated choice surveys are used extensively in the study of choice behaviour across many different areas of research, notably in transport. One of their main characteristics in comparison with most types of revealed preference (RP) surveys is the ability to capture behaviour by the same respondent under varying choice scenarios. While this ability to capture multiple choices is generally seen as an advantage, there is a certain amount of unease about survey length. The precise definition about what constitutes a large number of choice tasks however varies across disciplines, and it is not uncommon to see surveys with up to twenty tasks per respondent in some areas. The argument against this practice has always been one of reducing respondent engagement, which could be interpreted as a result of fatigue or boredom, with frequent reference to the findings of Bradley and Daly (1994) who showed a significant drop in utility scale, i.e. an increase in error, as a respondent moved from one choice experiment to the next, an effect they related to respondent fatigue. While the work by Bradley and Daly has become a standard reference in this context, it should be recognised that not only was the fatigue part of the work based on a single dataset, but the state-of-the-art and the state-of-practice in stated choice survey design and implementation has moved on significantly since their study. In this paper, we review other literature and present a more comprehensive study investigating evidence of respondent fatigue across a larger number of different surveys. Using a comprehensive testing framework employing both Logit and mixed Logit structures, we provide strong evidence that the concerns about fatigue in the literature are possibly overstated, with no clear decreasing trend in scale across choice tasks in any of our studies. For the data sets tested, we find that accommodating any scale heterogeneity has little or no impact on substantive model results, that the role of constants generally decreases as the survey progresses, and that there is evidence of significant attribute level (as opposed to scale) heterogeneity across choice tasks. {\textcopyright} 2011 Elsevier Ltd.},
	author = {Hess, Stephane and Hensher, David A. and Daly, Andrew},
	doi = {10.1016/j.tra.2011.11.008},
	file = {:C$\backslash$:/Users/amitrani/Documents/Mendeley/Hess, Hensher, Daly - 2012 - Not bored yet - Revisiting respondent fatigue in stated choice experiments.pdf:pdf},
	isbn = {0965-8564},
	issn = {09658564},
	journal = {Transportation Research Part A: Policy and Practice},
	keywords = {Fatigue,Learning,Multiple data sets,Scale,Stated choice experiments,Willingness to pay},
	number = 3,
	pages = {626--644},
	title = {{Not bored yet - Revisiting respondent fatigue in stated choice experiments}},
	volume = 46,
	year = 2012,
	booktitle = {Transportation Research Board, 91st Annual Meeting},
	url = {http://www.sciencedirect.com/science/article/pii/S0965856411001777}
}
@inproceedings{Hess2012c,
	abstract = {Recent interest in the topic of random scale heterogeneity in discrete choice data has led to the development of specialised tools such as the G-MNL model, as well as repeated claims that studies which fail to separate scale heterogeneity from heterogeneity in individual coefficients are likely to produce biased results. Contrary to this, Hess and Rose (2012) show that separate identification of the two components is not in fact possible in a random coefficients model using a typical linear in parameters specification, and that any gains in performance are potentially just the result of more flexible distributional assumptions. On the other hand, linking scale heterogeneity to measured characteristics of the respondents is likely to yield only limited insights, while using respondent reported measures of survey understanding or analyst captured measures such as survey response time puts an analyst at risk of measurement error and endogeneity bias. The contribution made in this paper is to put forward a hybrid model in which survey engagement is treated as a latent variable which is used to model the values of a number of indicators of survey engagement in a measurement model component, as well as explaining scale heterogeneity within the choice model. This model overcomes some of the shortcomings of earlier work, permitting us to link part of the heterogeneity across respondents to differences in scale, while also allowing us to make use of indicators of survey engagement without risk of endogeneity bias. Results from an empirical application show a strong link between the two model components as well as arguably more reasonable substantive outputs for the choice model component. ?? 2013 Elsevier BV. All rights reserved.},
	author = {Hess, Stephane and Stathopoulos, Amanda},
	booktitle = {Transportation Research Board, 91st Annual Meeting},
	doi = {10.1016/j.jocm.2013.03.005},
	file = {:C$\backslash$:/Users/amitrani/Documents/Mendeley/Hess, Stathopoulos - 2012 - Linking response quality to survey engagement A combined random scale and latent variable approach.pdf:pdf},
	issn = 17555345,
	keywords = {Hybrid model,Latent variables,Random scale,Stated choice,Survey engagement},
	pages = {1--12},
	pmid = 18394806,
	title = {{Linking response quality to survey engagement: A combined random scale and latent variable approach}},
	volume = 7,
	year = 2012
}
@inproceedings{Hess2012d,
	author = {Hess, Stephane and Rose, John M.},
	booktitle = {Transportation Research Board, 91st Annual Meeting},
	file = {:C$\backslash$:/Users/amitrani/Documents/Mendeley/Hess, Rose - 2012 - Disentangling scale and coefficient heterogeneity in random coefficients models an exercise in futility.pdf:pdf},
	keywords = {discrete choice,geneity,mixed logit,random scale,scale hetero-,taste heterogeneity},
	number = {0},
	pages = {1--23},
	title = {{Disentangling scale and coefficient heterogeneity in random coefficients models : an exercise in futility}},
	volume = 44,
	year = 2012
}
@inproceedings{Hess2012e,
	abstract = {In recent years, we have seen an explosion of research seeking to understand the role that rules and heuristics might play in improving the predictive capability of discrete choice models, as well as delivering willingness to pay estimates for specific attributes that may (and often do) differ significantly from estimates based on a model specification that assumes all attributes are relevant. This paper adds to that literature in one important way--it explicitly recognises the endogeneity issues raised by typical attribute non-attendance treatments and conditions attribute parameters on underlying unobserved attribute importance ratings. We develop a hybrid model system involving attribute processing and outcome choice models in which latent variables are introduced as explanatory variables in both parts of the model, explaining the answers to attribute processing questions and explaining heterogeneity in marginal sensitivities in the choice model. The resulting empirical model explains how lower latent attribute importance leads to a higher probability of indicating that an attribute was ignored or that it was ranked as less important, as well as increasing the probability of a reduced value for the associated marginal utility coefficient in the choice model. The model does so by treating the answers to information processing questions as dependent rather than explanatory variables, hence avoiding potential risk of endogeneity bias and measurement error.},
	author = {Hess, Stephane and Hensher, David A.},
	booktitle = {Transportation Research Board, 91st Annual Meeting},
	doi = {10.1007/s11116-012-9420-y},
	file = {:C$\backslash$:/Users/amitrani/Documents/Mendeley/Hess, Hensher - 2012 - Making use of respondent reported processing information to understand attribute importance A latent variable sca.pdf:pdf},
	isbn = {0049-4488},
	issn = {00494488},
	keywords = {Attribute ignoring,Attribute importance,Attribute relevance,Information processing,Non-attendance,Stated choice},
	number = 2,
	pages = {397--412},
	title = {{Making use of respondent reported processing information to understand attribute importance: A latent variable scaling approach}},
	volume = 40,
	year = 2012
}
@inproceedings{Hess2012f,
	abstract = {Wordcount: 5,606 words, 4 tables = 6,606 words 5 Abstract 6 There is growing interest in the notion that when responding to the hypothet-7 ical scenarios faced in a stated choice survey, a respondent may make his/her 8 choices on the basis of only a subset of the presented attributes. Research on 9 how to adequately capture such behaviour in data, and how to accommodate it 10 in our models, has made substantial headway in recent years. Two main schools 11 of thought exist for the reasons of such attribute non-attendance. Some see it 12 as evidence of respondent burden, while others will point to the notion that re-13 spondents decide first which attributes are relevant, before making their choices 14 based on that subset of attributes. Either way, the impact of any unimportant 15 attributes on the estimates of other valuations is unclear, where the focus in the 16 literature has been on the sample level estimates only of the attribute in ques-17 tion. This paper presents evidence from a two stage survey where the second stage 18 eliminates attributes deemed unimportant by a respondent in the first stage. Our 19 analysis shows no evidence of systematic differences between the results of the 20 two games, suggesting that the impact of such attributes on other valuations is 21 minimal at best. This further leads to the conclusion that analysts should not 22 be overly concerned about respondent burden, but should rather include all at-23 tributes that may be relevant, and allow the respondent to filter out those that 24 play no role. Tel: +44 (0)113 34 36611, Fax: +44 (0)113 343 5334},
	author = {Hess, Stephane},
	booktitle = {Transportation Research Board, 91st Annual Meeting},
	file = {:C$\backslash$:/Users/amitrani/Documents/Mendeley/Hess - 2012 - Impact of unimportant attributes in stated choice surveys.pdf:pdf},
	keywords = {attribute ignoring,attribute relevance,dent burden,information processing,non-attendance,respon-,stated choice},
	number = 2010,
	pages = {1--23},
	title = {{Impact of unimportant attributes in stated choice surveys}},
	url = {http://trid.trb.org/view.aspx?id=1129503},
	volume = 14,
	year = 2012
}
@article{Hess2013,
	abstract = {With the growing interest in the topic of attribute non-attendance, there is now widespread use of latent class (LC) structures aimed at capturing such behaviour, across a number of different fields. Specifically, these studies rely on a confirmatory LC model, using two separate values for each coefficient, one of which is fixed to zero while the other is estimated, and then use the obtained class probabilities as an indication of the degree of attribute non-attendance. In the present paper, we argue that this approach is in fact misguided, and that the results are likely to be affected by confounding with regular taste heterogeneity. We contrast the confirmatory model with an exploratory LC structure in which the values in both classes are estimated. We also put forward a combined latent class mixed logit model (LC-MMNL) which allows jointly for attribute non-attendance and for continuous taste heterogeneity. Across three separate case studies, the exploratory LC model clearly rejects the confirmatory LC approach and suggests that rates of non-attendance may be much lower than what is suggested by the standard model, or even zero. The combined LC-MMNL model similarly produces significant improvements in model fit, along with substantial reductions in the implied rate of attribute non-attendance, in some cases even eliminating the phenomena across the sample population. Our results thus call for a reappraisal of the large body of recent work that has implied high rates of attribute non-attendance for some attributes. Finally, we also highlight a number of general issues with attribute non-attendance, in particular relating to the computation of willingness to pay measures.},
	author = {Hess, Stephane and Stathopoulos, Amanda and Campbell, Danny and O'Neill, Vikki and Caussade, Sebastian},
	doi = {10.1007/s11116-012-9438-1},
	file = {:C$\backslash$:/Users/amitrani/Documents/Mendeley/Hess et al. - 2013 - It's not that I don't care, I just don't care very much Confounding between attribute non-attendance and taste hete.pdf:pdf},
	isbn = 1111601294381,
	issn = {00494488},
	journal = {Transportation},
	keywords = {Attribute ignoring,Attribute non-attendance,Choice modelling,Stated choice,Taste heterogeneity},
	number = 3,
	pages = {583--607},
	title = {{It's not that I don't care, I just don't care very much: Confounding between attribute non-attendance and taste heterogeneity}},
	volume = 40,
	year = 2013
}
@inproceedings{Hess2013a,
	abstract = {In a large-scale urban evacuation necessitated by a disaster, many people can evacuate in their own automobiles, but evacuating individuals and families who do not have cars poses a great logistical challenge that many cities, counties, and states cannot overcome. Most emergency operations plans for large urbanized areas are insufficient in describing in specific and measurable terms how a major evacuation could be successfully conducted. This study systematically reviews the challenge of multimodal evacuation planning and presents a detailed literature review of published research and government documents to identify barriers to the enhancement of multimodal evacuation planning through the use of high-capacity vehicles to transport those who cannot evacuate on their own. Findings suggest that despite knowledge about multimodal transportation and the importance of integrating multimodalism into evacuation planning, most state and local governments do not apply the planning processes, training exercises, and resources necessary to evacuate households without automobiles. A research agenda for furthering multimodal evacuation planning is outlined, and recommendations are made for providing adequate multimodal transport during large-scale urban evacuations.},
	author = {Hess, Daniel Baldwin and Conley, Brian W and Farrell, Christina M},
	booktitle = {Transportation Research Board, 92nd Annual Meeting},
	doi = {10.3141/2376-02},
	file = {:C$\backslash$:/Users/amitrani/Documents/Mendeley/Hess, Conley, Farrell - 2013 - Improving Transportation Resource Coordination for Multimodal Evacuation Planning Literature Review and R.pdf:pdf},
	issn = {0361-1981},
	number = 2376,
	pages = {11--19},
	title = {{Improving Transportation Resource Coordination for Multimodal Evacuation Planning Literature Review and Research Agenda}},
	year = 2013
}
@inproceedings{Hess2013b,
	abstract = {Using data from a stated preference survey conducted in the UK, we show how the relative importance that rail travellers attach to reductions in greenhouse gas emissions and faster journey times varies strongly as a function of underlying attitudes towards the environment. We specify a latent class structure that allocates respondents to two classes with substantially different valuations of greenhouse gas emissions, and show how the allocation of a given respondent to either class is a function of underlying attitudes that also drive the answers to a number of attitudinal questions. We also show how these underlying attitudes are a function of a number of socio-demographic characteristics, with female respondents, older respondents, and respondents with a university degree having a stronger pro-environmental attitude, with the opposite applying to respondents with regular car access. ?? 2013 Elsevier Ltd.},
	author = {Hess, Stephane and Shires, Jeremy and Jopson, Ann},
	booktitle = {Transportation Research Board, 92nd Annual Meeting},
	doi = {10.1016/j.trd.2013.07.003},
	file = {:C$\backslash$:/Users/amitrani/Documents/Mendeley/Hess, Shires, Jopson - 2013 - Accommodating underlying pro-environmental attitudes in a rail travel context Application of a latent vari.pdf:pdf},
	isbn = {1361-9209},
	issn = 13619209,
	keywords = {Environmental attitudes,Greenhouse gas emissions,Rail transport,Stated preference method},
	pages = {42--48},
	title = {{Accommodating underlying pro-environmental attitudes in a rail travel context: Application of a latent variable latent class specification}},
	volume = 25,
	year = 2013
}
@inproceedings{Hess2013c,
	abstract = {Income is recognised as a key variable influencing consumer behaviour, most notably in terms of a strong link with cost sensitivity. This is sup-ported by a large body of empirical evidence using choice modelling tech-niques. Unfortunately, income information as available in most datasets used for modelling is affected by a number of issues; (1) it is measured as a categorical rather than as a continuous variable, (2) many respondents fail to provide income information, (3) the reported income is potentially correlated with other unobserved factors, and (4) there is scope for delib-erate under or overstating of income by respondents. In the present paper, we propose to deal with these issues by replacing reported income with a latent income variable in the choice models, which at the same time is also used to explain the stated income in a measurement model. The proposed structure has a number of theoretical advantages. In comparison with using stated income, we should deal with some of the measurement error and bias issues. In comparison with using imputation of missing values, our model draws not just on data on stated income for those re-spondents without missing information, but the simultaneous estimation with the choice model means that the observed choices also inform the la-tent income variable. Two empirical applications using stated and revealed preference data illustrate the good performance of the method in practice.},
	author = {Hess, Stephane and Daly, Andrew and Dumont, Jeff and Sanko, Nobuhiro},
	booktitle = {Transportation Research Board, 92nd Annual Meeting},
	file = {:C$\backslash$:/Users/amitrani/Documents/Mendeley/Hess et al. - 2013 - When explanatory variables are unobserved the example of latent income.pdf:pdf},
	keywords = {discrete choice,latent variables,missing income,random het-erogeneity},
	pages = {1--14},
	title = {{When explanatory variables are unobserved: the example of latent income}},
	year = 2013
}
@inproceedings{Hess2014,
	abstract = {5 An increasing number of choice models models have been proposed to examine respondents' use 6 of heterogeneous decision rules. The focus has been on revealing which paradigm fits best for a given 7 respondent or class of respondents, or for a given choice characteristic. On the other hand, limited 8 effort has gone towards understanding the motivation behind the use of different decision rules. This 9 paper presents a model that creates a link between real world behavioural indicators and the use of 10 decision paradigms in a stated choice context. An empirical application is developed as a latent class 11 mixture between regret minimisation and utility maximisation where the allocation to a given class is 12 driven in part by a latent variable which also, in a separate measurement model, explains respondents' 13 stated satistfaction with their real world reference commute journey (in terms of differences between 14 experienced and ideal travel performance). Results reveal a linkage between the likely decision rule 15 and the stated satisfaction with the real world commute where the most regret-prone respondents in 16 our sample are more likely to have aligned their real-life commute performance to their aspirational 17 values.},
	author = {Hess, Stephane},
	booktitle = {Transportation Research Board, 93rd Annual Meeting},
	file = {:C$\backslash$:/Users/amitrani/Documents/Mendeley/Hess - 2014 - Linking the decision process to indicators of real world perceptions in a latent variable latent class approach.pdf:pdf},
	keywords = {2 figures and 2,265 words,5,6,decision rules,hybrid models,latent class,random regret,random utility,tables,word count},
	number = {0},
	title = {{Linking the decision process to indicators of real world perceptions in a latent variable latent class approach}},
	volume = 44,
	year = 2014
}
@inproceedings{Hess2014a,
	abstract = {An increasing number of studies of choice behaviour are looking at Random Regret Minimisation (RRM) as an alternative to the well established Random Utility Maximisation (RUM) framework. Empirical evidence tends to show small differences in performance between the two approaches, with the implied preference between the models being dataset specific. In the present paper, we discuss how in the context of choice tasks involving an opt out alternative, the differences are potentially more clear cut. Specifically, we hypothesise that when opt out alternatives are framed as a rejection of all the available alternatives, this is likely to have a detrimental impact on the performance of RRM, while the performance of RUM suffers more than RRM when the opt out is framed as a respondent being indifferent between the alternatives on offer. We provide empirical support for these hypotheses through two case studies, using the two different types of opt out alternatives. Our findings suggest that analysts need to carefully evaluate their choice of model structure in the presence of opt out alternatives, while any a priori preference for a given model structure should be taken into account in survey framing. ?? 2014 Elsevier Ltd.},
	author = {Hess, Stephane and Beck, Matthew J. and Chorus, Caspar G.},
	booktitle = {Transportation Research Board, 93rd Annual Meeting},
	doi = {10.1016/j.tra.2014.04.004},
	file = {:C$\backslash$:/Users/amitrani/Documents/Mendeley/Hess, Beck, Chorus - 2014 - Contrasts between utility maximisation and regret minimisation in the presence of opt out alternatives.pdf:pdf},
	isbn = {0965-8564},
	issn = {09658564},
	keywords = {Decision rules,Opt out alternatives,Random regret minimisation,Stated choice},
	number = 1,
	pages = {1--12},
	title = {{Contrasts between utility maximisation and regret minimisation in the presence of opt out alternatives}},
	volume = 66,
	year = 2014
}
@inproceedings{Hess2014b,
	abstract = {This paper presents a novel application in route choice modelling using Global Positioning System (GPS) data, focussing on heavy goods vehicles which typically make longer journeys with decisions potentially underpinned by different priorities from those used by car drivers. The scope of the study is larger than many previous ones, using the entire road network of England. Making use of the error components model put forward for route choice by Frejinger and Bierlaire (2007), the work reveals low elasticities in response to changes in travel time, reflecting the limited opportunity for avoiding specific roads on long distance journeys by heavy goods vehicles.},
	author = {Hess, Stephane and Quddus, Mohammed and Rieser-Sch{\"{u}}ssler, Nadine and Daly, Andrew},
	booktitle = {Transportation Research Board, 93rd Annual Meeting},
	doi = {10.1016/j.tre.2015.01.010},
	file = {:C$\backslash$:/Users/amitrani/Documents/Mendeley/Hess et al. - 2014 - Developing advanced route choice models for heavy goods vehicles using GPS data.pdf:pdf},
	isbn = {1366-5545},
	issn = 13665545,
	keywords = {Error components,GPS data,Heavy goods vehicles,Route choice},
	pages = {29--44},
	title = {{Developing advanced route choice models for heavy goods vehicles using GPS data}},
	volume = 77,
	year = 2014
}
@inproceedings{Hess2015,
	author = {Hess, S and Chorus, CG},
	booktitle = {Transportation Research Board, 94th Annual Meeting},
	file = {:C$\backslash$:/Users/amitrani/Documents/Mendeley/Hess, Chorus - 2015 - Utility Maximisation and Regret Minimisation A Mixture of a Generalisation.pdf:pdf},
	isbn = 9781784410728,
	pages = {31 -- 48},
	title = {{Utility Maximisation and Regret Minimisation: A Mixture of a Generalisation}},
	url = {https://books.google.cl/books?hl=es{\&}lr={\&}id=RwSLBgAAQBAJ{\&}oi=fnd{\&}pg=PA31{\&}ots=bvrG3C87Tx{\&}sig=4tfRoUmlciwPBylLq5aT6Hakxrc},
	year = 2015
}
@article{Hess2016,
	abstract = {See, stats, and : https : / / www . researchgate . net / publication / 309734001 A , heteroscedasticity , non - linearity , reference dependence . . . Article CITATIONS 0 READS 9 6 , including : Stephane University 111 , 122 SEE Andrew University 82 , 841 SEE Thijs University 25 SEE All - text , letting . Available : Stephane Retrieved : 08 Abstract In early 2014 , the UK Department for Transport (DfT) commissioned the first national value of travel time (VTT) study since the mid - 1990s . This paper presents the methodological work undertaken for this study , with important innovations along a number of dimensions , both in terms of survey design and modelling methodology . Our findings show a rich pattern of heterogeneity across the travelling public , in terms of an impact on the VTT by both person and trip characteristics , as well as a major role for a number of characteristics that relate to the specific choices faced in a hypothetical stated choice setting , including reference dependence and non - linearities in sensitivities . We also discuss how these behavioural values were translated into values for use in appraisal , and the challenges faced when doing this on the basis of results obtained with advanced models .},
	author = {Hess, Stephane and Daly, Andrew and Dekker, Thijs and Cabral, Manuel Ojeda and Batley, Richard},
	file = {:C$\backslash$:/Users/amitrani/Documents/Mendeley/Hess et al. - 2016 - A framework for capturing heterogeneity , heteroscedasticity , non - linearity , reference dependence and design ar.pdf:pdf},
	journal = {Transportation Research Part B Methodological},
	number = {November},
	title = {{A framework for capturing heterogeneity , heteroscedasticity , non - linearity , reference dependence and design artefacts in value of time research}},
	year = 2016
}
@article{Hess2016a,
	author = {Hess, Stephane and B{\"{o}}rjesson, Maria},
	file = {:C$\backslash$:/Users/amitrani/Documents/Mendeley/Hess, B{\"{o}}rjesson - 2016 - Understanding attitudes towards congestion pricing a latent variable investigation with data from four cities.pdf:pdf},
	journal = {Transportation Letters The International Journal of Transportation Research},
	number = {December},
	title = {{Understanding attitudes towards congestion pricing: a latent variable investigation with data from four cities}},
	year = 2016
}
@inproceedings{Hess2017,
	address = {Washington D.C.},
	author = {Hess, Stephane and Daly, Andrew and B{\"{o}}rjesson, Maria},
	booktitle = {Transportation Research Board, 96th Annual Meeting},
	file = {:C$\backslash$:/Users/amitrani/Documents/Mendeley/Hess, Daly, B{\"{o}}rjesson - 2017 - A critical appraisal of the use of simple time-money trade-offs for appraisal value of time measures.pdf:pdf},
	title = {{A critical appraisal of the use of simple time-money trade-offs for appraisal value of time measures}},
	year = 2017
}
@inproceedings{Hess2017a,
	author = {Hess, Jacob Robert},
	booktitle = {Transportation Research Board, 96th Annual Meeting},
	file = {:C$\backslash$:/Users/amitrani/Documents/Mendeley/Hess - 2017 - Outlier Mining Based Traffic Incident Detection Using Big Data.pdf:pdf},
	number = 765,
	title = {{Outlier Mining Based Traffic Incident Detection Using Big Data}},
	year = 2017
}
`;

test('merge duplicates 2', async () => {
	const tidied = await bibtexTidy(input, {
		merge: true,
		tab: true,
		align: false,
		encodeUrls: false,
		escape: false,
	});
	strictEqual(tidied.bibtex, output);
	//strictEqual(tidied.warnings, 0);
});
